##############
django-anysign
##############

`django-anysign` is a Django application to manage online signature in a
generic way.

Its goal is to provide a consistent API whatever the signature implementation,
so that you can either:

* switch from one signature backend to another;
* use several backends at once.

See `Alternatives & related projects`_ for details about supported online
signature services.


**************
Project status
**************

`django-anysign` is under active development. The project is not mature yet,
but authors already use it! It means that, while API and implementation may
change (improve!), authors do care of the changes.

Also, help is welcome! Feel free to report issues, request features or
refactoring!


*********
Resources
*********

* Documentation: https://django-anysign.readthedocs.org
* Bugtracker: https://github.com/novafloss/django-anysign/issues
* Changelog: https://django-anysign.readthedocs.org/en/latest/about/changelog.html
* Roadmap: https://github.com/novafloss/django-anysign/milestones
* Code repository: https://github.com/novafloss/django-anysign
* Continuous integration: https://travis-ci.org/novafloss/django-anysign

.. _`Alternatives & related projects`:
   https://django-anysign.readthedocs.org/en/latest/about/alternatives.html
